<?php
class FileDumpEIDHook implements \TYPO3\CMS\Core\Resource\Hook\FileDumpEIDHookInterface {

    /**
   * Perform custom security/access when accessing file
   * Method should issue 403 if access is rejected
   * or 401 if authentication is required
   *
   * @param \TYPO3\CMS\Core\Resource\ResourceInterface $file
   * @return void
   */
  public function checkFileAccess(\TYPO3\CMS\Core\Resource\ResourceInterface $file) {

      // deny access to file if no BE user is logged in
      if(!($this->fileStorageIsActive($file->getStorage()) && ($file->getStorage()->isPublic() || $this->isAuthorizedBackendSession($file)))) {
        echo "Access denied";
        \TYPO3\CMS\Core\Utility\HttpUtility::setResponseCodeAndExit(\TYPO3\CMS\Core\Utility\HttpUtility::HTTP_STATUS_403);
        exit;
      }
  }

  /**
  * Checks if a given $fileStorage is active and not hidden nor deleted
  *
  * @return boolean
  */
  protected function fileStorageIsActive(\TYPO3\CMS\Core\Resource\ResourceStorage $fileStorage) {
    $storageRecord = $fileStorage->getStorageRecord();
    return ($storageRecord['deleted'] == 0 && $storageRecord['hidden'] == 0 && $fileStorage->isOnline() && $fileStorage->isBrowsable());
  }

    /**
   * Checks if a BE user is logged in and the session is active and BE user
   * has access to file storage
   *
   * @return boolean
   */
  protected function isAuthorizedBackendSession(\TYPO3\CMS\Core\Resource\ResourceInterface $file) {
    \TYPO3\CMS\Core\Core\Bootstrap::getInstance()->initializeBackendUser();
    $loggedInBEUser = isset($GLOBALS['BE_USER']) && $GLOBALS['BE_USER'] instanceof \TYPO3\CMS\Core\Authentication\BackendUserAuthentication && isset($GLOBALS['BE_USER']->user['uid']);
    $fileAccessAllowed = false;
    if($loggedInBEUser) {
      $fileStorageUid = $file->getStorage()->getUid();
      foreach($GLOBALS['BE_USER']->getFileStorages() as $fileStorage) {
        if($fileStorage->getUid() == $fileStorageUid){
          $fileAccessAllowed = true;
          break;
        }
      }
    }
    return $loggedInBEUser && $fileAccessAllowed;
  }
}
